====================================
:mod:`numina.user` --- CLI interface
====================================

.. automodule:: numina.user
   :synopsis: User command line interface for Numina
   :members:
   